{% load cms_tags menu_tags staticfiles sekizai_tags thumbnail %}
<figure class="picture slide"
        style="height: {{ slider_height }}; margin: 0 {{ horizontal_margin }};">
  {% for plugin in instance.child_plugin_instances %}
    {% render_plugin plugin %}
  {% endfor %}
  {% if instance.show_caption and instance.caption_text %}
    <figcaption>
      {{ instance.caption_text }}
    </figcaption>
  {% endif %}
</figure>
