# -*- coding: utf-8 -*-

from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class RototalcConfig(AppConfig):
    name = 'ripiu.cmsplugin_rototalc'
    verbose_name = _('Carousel')
