# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2017-12-07 14:12
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cmsplugin_rototalc', '0002_carouselplugin_initial_slide'),
    ]

    operations = [
        migrations.AddField(
            model_name='carouselplugin',
            name='heading_level',
            field=models.PositiveSmallIntegerField(choices=[(1, 'H1'), (2, 'H2'), (3, 'H3'), (4, 'H4'), (5, 'H5'), (6, 'H6')], default=2, help_text='Choose a heading level', verbose_name='heading level'),
        ),
        migrations.AddField(
            model_name='carouselplugin',
            name='subtitle',
            field=models.CharField(blank=True, default='', max_length=400, verbose_name='subtitle'),
        ),
        migrations.AddField(
            model_name='carouselplugin',
            name='title',
            field=models.CharField(blank=True, default='', max_length=400, verbose_name='title'),
        ),
    ]
